<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field</source>
        <translation>Campo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field name</source>
        <translation>Nome campo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Field description</source>
        <translation>Descrizione campo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Field value</source>
        <translation>Campo valore</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Esci alla chiusura</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Ricorda posizione</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Ricerca del nome host</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Ricerca del nome del servizio</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Triangoli di rivelazione</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Diramazioni</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Salva automaticamente le impostazioni alla chiusura</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Selezione: Copia PID negli Appunti</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normalizza NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Usa pmap per il nome delle mappe</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Lineare</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Albero</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Thread</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Tutti processi</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Processi propri</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Processi non-amministratore</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Processi in esecuzione</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pausa (Ctrl+Spazio)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Processo %1 (%2) - dettagli</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Socket</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Mappa memoria</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Ambiente</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Tutti i campi</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable</source>
        <translation>Variabile</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable name</source>
        <translation>Nome variabile</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Variable value</source>
        <translation>Valore variabile</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Seleziona campi personalizzati </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>File descriptor</source>
        <translation>Descrittore file</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Open mode</source>
        <translation>Modalità apertura</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File name (if available)</source>
        <translation>Nome file (se disponibile)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="782"/>
        <source>I/O Summary:</source>
        <translation>Riepilogo I/O:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="816"/>
        <source>No input or output</source>
        <translation>Nessun input o output</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Periodo aggiornamento cambiamenti</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Nuovo periodo di aggiornamento</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>Nessun AGGIORNAMENTO</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Valore invalido</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Intervallo Indirizzi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Indirizzi mappati (hex) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Kbytes mappati (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>Permessi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Flag di autorizzazione</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Scostamento</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Indirizzo del file all&apos;inizio della mappa (esadecimale)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Numeri di dispositivo maggiore e minore (decimale)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>Inode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Numero inode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Nome file (se disponibile)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Permesso</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Password amministratore</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Impostazione</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%CPU divisa da</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Totale cpu: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>Cpu singola: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>predefinito</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>per sviluppatori</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2618"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2618"/>
        <source>Process ID</source>
        <translation>ID Processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2620"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2620"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>ID gruppo processi ( genitore dei thread )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2622"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2622"/>
        <source>Parent process ID</source>
        <translation>ID processo genitore</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2624"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2624"/>
        <source>Process group ID</source>
        <translation>ID gruppo processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2626"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2626"/>
        <source>Session ID</source>
        <translation>ID sessione</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2628"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2628"/>
        <source>Terminal</source>
        <translation>Terminale</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2630"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2630"/>
        <source>Process group ID of tty owner</source>
        <translation>ID processo di gruppo del proprietario del tty</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2632"/>
        <source>USER</source>
        <translation>UTENTE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2632"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Proprietario (*=suid root, +=suid a user)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2634"/>
        <source>GROUP</source>
        <translation>GRUPPO</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2634"/>
        <source>Group name (*=sgid other)</source>
        <translation>Nome gruppo (*=sgid altri)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2636"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2636"/>
        <source>Real user ID</source>
        <translation>ID utente reale</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2638"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2638"/>
        <source>Effective user ID</source>
        <translation>ID utente effettivo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2640"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2640"/>
        <source>Saved user ID (Posix)</source>
        <translation>ID utente salvato (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2642"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2642"/>
        <source>File system user ID</source>
        <translation>ID utente filesystem</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2644"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2644"/>
        <source>Real group ID</source>
        <translation>ID gruppo reale</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2646"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2646"/>
        <source>Effective group ID</source>
        <translation>ID gruppo effettivo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2648"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2648"/>
        <source>Saved group ID (Posix)</source>
        <translation>ID gruppo salvato (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2650"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2650"/>
        <source>File system group ID</source>
        <translation>ID gruppo filesystem</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2652"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2652"/>
        <source>Dynamic priority</source>
        <translation>Proprietà dinamica</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2654"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2654"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Pianificazione risorse (maggiore -&gt; meno tempo CPU)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2656"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2656"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Numero di task (thread) nel gruppo di task</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2658"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2658"/>
        <source>Scheduling policy</source>
        <translation>Politica di scheduling</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2660"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2660"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Priorità realtime (0-99, più è meglio)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2662"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2662"/>
        <source>Time slice in milliseconds</source>
        <translation>Frazione di tempo in millisecondi</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2664"/>
        <source>%SAVG</source>
        <translation>%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2664"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Percentuale media tempo di riposo (-1 -&gt; N/A)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2666"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2666"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Maschera affinità CPU (0 -&gt; API not supported)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2668"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2668"/>
        <source>Number of major faults (disk access)</source>
        <translation>Numero di errori gravi (accesso al disco)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Numero di errori lievi (nessun accesso al disco)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2673"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2673"/>
        <source>Virtual image size of process</source>
        <translation>Immagine virtuale della dimensione del processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2675"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2675"/>
        <source>Resident set size</source>
        <translation>Dimensione del set residente</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2677"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2677"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>Utilizzo memoria (RSS-CONDIVISA)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2679"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2679"/>
        <source>Text(code) resident set size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2681"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2681"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2683"/>
        <source>STACK</source>
        <translation type="unfinished">STACK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2683"/>
        <source>Stack size</source>
        <translation>Dimensione stack</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2685"/>
        <source>SHARE</source>
        <translation type="unfinished">SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2685"/>
        <source>Shared memory with other libs</source>
        <translation>Memoria condivisa con altre librerie</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2687"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2687"/>
        <source>Kbytes on swap device</source>
        <translation>Kbyte sul dispositivo di swap</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2689"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2689"/>
        <source>io read (file)</source>
        <translation>io lettura (file)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2691"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2691"/>
        <source>io write (file)</source>
        <translation>io scrittura (file)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2693"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2693"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Numero di pagine sporche (non scritte)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2695"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2695"/>
        <source>State of the process </source>
        <translation>Stato del processo </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2697"/>
        <source>FLAGS</source>
        <translation>FLAG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2697"/>
        <source>Process flags (hex)</source>
        <translation>Flag processo (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2699"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2699"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Funzione kernel su cui il processo è in pausa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2701"/>
        <source>%WCPU</source>
        <translation>%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2701"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Percentuale pesata di CPU (media di 30 s)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2703"/>
        <source>%CPU</source>
        <translation>%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2703"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Percentuale della CPU usata dall&apos;ultimo aggiornamento</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2705"/>
        <source>%MEM</source>
        <translation>%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2705"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Percentuale di memoria usata (RSS/memoria totale)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2707"/>
        <source>START</source>
        <translation>AVVIO</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2707"/>
        <source>Time process started</source>
        <translation>Momento di avvio del processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2709"/>
        <source>TIME</source>
        <translation>TEMPO</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2709"/>
        <source>Total CPU time used since start</source>
        <translation>Totale del tempo CPU usato dall&apos;avvio</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2711"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2711"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>CPU sulla quale il processo è in esecuzione (sistema SMP)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2713"/>
        <source>the process name</source>
        <translation>Il nome del processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2713"/>
        <source>Process Name</source>
        <translation>Nome processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2717"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2717"/>
        <source>Current working directory</source>
        <translation>Cartella di lavoro corrente</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Root directory of process</source>
        <translation>Cartella principale del processo</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2721"/>
        <source>COMMAND_LINE</source>
        <translation>RIGA_DI_COMANDO</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2721"/>
        <source>Command line that started the process</source>
        <translation>Riga di comando che ha avviato il processo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1638"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1641"/>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1646"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Utente: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Sistema: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Priorità: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="471"/>
        <location filename="../infobar.cpp" line="506"/>
        <source>Total: </source>
        <translation>Totale: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="512"/>
        <source>Used: </source>
        <translation>Usati: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="478"/>
        <source>Cached: </source>
        <translation>In cache: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Buffer: </source>
        <translation>Buffer: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="509"/>
        <source>Free: </source>
        <translation>Liberi: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="551"/>
        <source>Time passed after system boot</source>
        <translation>Tempo passato dopo l&apos;avvio del sistema</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="579"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Carico medio della CPU ogni 1, 5, 15 minuti</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="724"/>
        <source>CPU Usage Summary:</source>
        <translation>Riepilogo utilizzo CPU:</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="174"/>
        <source>header_popup</source>
        <translation>Pop-up testata</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="175"/>
        <source>Remove Field</source>
        <translation>Rimuovi campo</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Add Field</source>
        <translation>Aggiungi campo</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="179"/>
        <source>Session</source>
        <translation>Sessione</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="183"/>
        <source>View</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="184"/>
        <source>Process</source>
        <translation>Processo</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="185"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Fields</source>
        <translation>Campi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="191"/>
        <source>Custom Fields</source>
        <translation>Campi personalizzati</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="193"/>
        <source>Basic Fields </source>
        <translation>Campi di base </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="195"/>
        <source>Jobs Fields </source>
        <translation>Campi processi </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Memory Fields </source>
        <translation>Campi memoria </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="200"/>
        <source>Scheduling Fields </source>
        <translation>Campi pianificazione </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="217"/>
        <source>Select Custom Fields...</source>
        <translation>Seleziona campi personalizzati...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="226"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="227"/>
        <source>Update Period...</source>
        <translation>Periodo aggiornamento...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="236"/>
        <source>Show Status bar</source>
        <translation>Mostra barra di stato</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="245"/>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="251"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="252"/>
        <location filename="../qps.cpp" line="1686"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="338"/>
        <source>test</source>
        <translation>test</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="339"/>
        <source>Copied to Clipboard</source>
        <translation>Copiato negli Appunti</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="391"/>
        <source>context popup</source>
        <translation>popup contestuale</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Renice...</source>
        <translation>Cambia nice...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="393"/>
        <source>Scheduling...</source>
        <translation>Pianificazione...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Terminate</source>
        <translation>Termina</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="397"/>
        <source>Hangup</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="398"/>
        <source>Kill</source>
        <translation>Uccidi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="399"/>
        <source>Stop</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="401"/>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="404"/>
        <source>Other Signals</source>
        <translation>Altri segnali</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="405"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (interrompi)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="407"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (continua)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="409"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (stop)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (esci)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="413"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (istruzione illegale)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="415"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (abortisci)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="417"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (errore virgola mobile)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="419"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (violazione segmentazione)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="421"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (pipe rotto)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="423"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (segnale timer)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="425"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (definito dall&apos;utente 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="427"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (definito dall&apos;utente 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="429"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (figlio morto)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="431"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (interrompi dal tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="433"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (input tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="435"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (output tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="442"/>
        <source>View Details</source>
        <translation>Mostra dettagli</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="695"/>
        <source>Show File Path</source>
        <translation>Mostra percorso file</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="701"/>
        <source>Show Graph</source>
        <translation>Mostra grafico</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="707"/>
        <source>Show Control Bar</source>
        <translation>Mostra barra di controllo</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="718"/>
        <source>Include Child Times</source>
        <translation>Includi tempi dei processi figli</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="290"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1163"/>
        <location filename="../qps.cpp" line="1194"/>
        <location filename="../qps.cpp" line="1201"/>
        <location filename="../qps.cpp" line="1222"/>
        <location filename="../qps.cpp" line="1256"/>
        <location filename="../qps.cpp" line="1351"/>
        <source>Permission denied</source>
        <translation>Permesso negato</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1164"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Non hai i permessi di cambiare il nice dei processi selezionati. Solo il proprietario del processo e l&apos;amministratore hanno il permesso di farlo.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1195"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Non hai i permessi di cambiare il nice al processo %1 (%2). Solo il proprietario e l&apos;amministratore hanno il permesso di farlo.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1202"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Solo l&apos;amministratore può abbassare il nice di un processo.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1223"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Solo l&apos;utente root può modificare la politica di pianificazione e la priorità statica.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1257"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Non disponi dell&apos;autorizzazione per modificare la pianificazione e / o la priorità del processo% 1 (% 2). Solo root può farlo.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1318"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Si è sicuro di voler terminare il/i processo/i selezionati?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1320"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Si è sicuro di voler sospendere il/i iprocesso/i selezionati?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1322"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Si è sicuro di voler uccidere il/i iprocesso/i selezionati?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1331"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1352"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Non hai l&apos;autorizzazione per inviare un segnale per elaborare% 1 (% 2). Solo root e il proprietario del processo possono inviargli dei segnali.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1702"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1704"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - Un gestore processi visuale &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Sorgenti: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1724"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Qps originale da&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Collaboratori&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Modifica la pianificazione</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Politica di pianificazione</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (tempo reale)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (tempo reale)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Priorità (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Inserimento non valido</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>La priorità deve essere tra 1 e 99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, COMANDO,UTENTE...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Procedura di allocazione delle risorse</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Nuovo valore nice:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation type="unfinished">Descrittore file</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation type="unfinished">Proto</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protocollo (TCP o UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation>Recv-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Byte nella coda di ricezione</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation>Send-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Byte nella coda di invio</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Addr locale</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Indirizzo IP locale</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Porta locale</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Addr remoto</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Indirizzo IP remoto</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Porta remota</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Stato</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Stato connessione</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Numero processi: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation>Questa è una feature alpha instabile
Forse vedrete un SEGFAULT...</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>Titolo</translation>
    </message>
</context>
</TS>
